@@ -7,7 +7,8 @@ data(sanction)
 user.prompt()
 z.out1 <- zelig(as.factor(cost) ~ mil + coop, model = "oprobit", 
                     data = sanction)
-summary(z.out1)
+user.prompt()
+print(summary(z.out1))
 
 # Set the explanatory variables to their means, with 'mil' set
 # to 0 (no military action in addition to sanctions) in the baseline
@@ -21,7 +22,8 @@ x.high <- setx(z.out1, mil = 1)
 # the results:
 user.prompt()
 s.out1 <- sim(z.out1, x = x.low, x1 = x.high)
-summary(s.out1)
+user.prompt()
+print(summary(s.out1))
 
 
 ##### Example 2: Creating An Ordered Dependent Variable #####
@@ -35,7 +37,8 @@ sanction$ncost <- factor(sanction$ncost, ordered = TRUE,
 # Z.Out the model:
 user.prompt()
 z.out2 <- zelig(ncost ~ mil + coop, model = "oprobit", data = sanction)
-summary(z.out2)
+user.prompt()
+print(summary(z.out2))
 
 # Set the explanatory variables to their observed values:  
 user.prompt()
@@ -44,7 +47,8 @@ x.out2 <- setx(z.out2, fn = NULL)
 # Simulate fitted values given Xval and view the results:
 user.prompt()
 s.out2 <- sim(z.out2, x = x.out2)
-summary(s.out2)
+user.prompt()
+print(summary(s.out2))
 
 
 
